@@ -2,45 +2,28 @@ from typing import Dict, Optional
 
 from .base import Base
 
-
 class MagicLinks(Base):
     @property
     def magic_link_url(self):
         return self.get_url("magic_links")
 
-    def _validate_attributes(self, attributes: Dict[str, str]) -> Dict[str, str]:
-        if not attributes:
-            return attributes
-        default_attributes = {"ip_address": "", "user_agent": ""}
+    def authenticate(
+        self,
+        token: str,
+        attributes: Optional[Dict] = None,
+        options: Optional[Dict] = None,
+    ):
+        attributes = self._validate_attributes(attributes)
+        options = self._validate_options(options)
 
-        if attributes.get("ip_address"):
-            default_attributes.update({"ip_address": attributes["ip_address"]})
-        if attributes.get("user_agent"):
-            default_attributes.update({"user_agent": attributes["user_agent"]})
-
-        return default_attributes
-
-    def _validate_match_attributes(self, attributes: Dict[str, str]) -> Dict[str, str]:
-        if not attributes:
-            return attributes
-
-        default_attributes = {"ip_address_match": "", "user_agent_match": ""}
-        if attributes.get("ip_address_match"):
-            default_attributes.update(
-                {"ip_address_match": attributes["ip_address_match"]}
-            )
-        if attributes.get("user_agent_match"):
-            default_attributes.update(
-                {"user_agent_match": attributes["user_agent_match"]}
-            )
-
-        return default_attributes
-
-    def authenticate(self, token: str, options: Dict = None):
-        options = self._validate_match_attributes(options)
+        data={}
+        if attributes:
+            data["attributes"] = attributes
+        if options:
+            data["options"] = options
         return self._post(
             "{0}/{1}/authenticate".format(self.magic_link_url, token),
-            data={"options": options},
+            data=data,
         )
 
     def send(
@@ -48,41 +31,47 @@ class MagicLinks(Base):
         method_id: str,
         user_id: str,
         magic_link_url: str,
-        expiration_minutes: int = 10,
+        expiration_minutes: Optional[int] = None,
         attributes: Optional[Dict] = None,
     ):
         attributes = self._validate_attributes(attributes)
+        data = {
+            "method_id": method_id,
+            "user_id": user_id,
+            "magic_link_url": magic_link_url,
+            "attributes": attributes,
+        }
+        if expiration_minutes:
+            data["expiration_minutes"] = expiration_minutes
+
         return self._post(
             "{0}/send".format(
                 self.magic_link_url,
             ),
-            data={
-                "method_id": method_id,
-                "user_id": user_id,
-                "magic_link_url": magic_link_url,
-                "expiration_minutes": expiration_minutes,
-                "attributes": attributes,
-            },
+            data=data,
         )
 
     def send_by_email(
         self,
         email: str,
         magic_link_url: str,
-        expiration_minutes: int = 10,
+        expiration_minutes: Optional[int] = None,
         attributes: Optional[Dict] = None,
     ):
         attributes = self._validate_attributes(attributes)
+        data = {
+            "email": email,
+            "magic_link_url": magic_link_url,
+            "attributes": attributes,
+        }
+        if expiration_minutes:
+            data["expiration_minutes"] = expiration_minutes
+
         return self._post(
             "{0}/send_by_email".format(
                 self.magic_link_url,
             ),
-            data={
-                "email": email,
-                "magic_link_url": magic_link_url,
-                "expiration_minutes": expiration_minutes,
-                "attributes": attributes,
-            },
+            data=data,
         )
 
     def login_or_create(
@@ -93,6 +82,7 @@ class MagicLinks(Base):
         login_expiration_minutes: Optional[int] = None,
         signup_expiration_minutes: Optional[int] = None,
         attributes: Optional[Dict] = None,
+        create_user_as_pending: Optional[bool] = None,
     ):
         attributes = self._validate_attributes(attributes)
         return self._post(
@@ -106,30 +96,7 @@ class MagicLinks(Base):
                 "login_expiration_minutes": login_expiration_minutes,
                 "signup_expiration_minutes": signup_expiration_minutes,
                 "attributes": attributes,
-            },
-        )
-
-    def login_or_invite_by_email(
-        self,
-        email: str,
-        login_magic_link_url: str,
-        invite_magic_link_url: str,
-        login_expiration_minutes: Optional[int] = None,
-        invite_expiration_minutes: Optional[int] = None,
-        attributes: Optional[Dict] = None,
-    ):
-        attributes = self._validate_attributes(attributes)
-        return self._post(
-            "{0}/login_or_invite".format(
-                self.magic_link_url,
-            ),
-            data={
-                "email": email,
-                "login_magic_link_url": login_magic_link_url,
-                "invite_magic_link_url": invite_magic_link_url,
-                "login_expiration_minutes": login_expiration_minutes,
-                "invite_expiration_minutes": invite_expiration_minutes,
-                "attributes": attributes,
+                "create_user_as_pending": create_user_as_pending,
             },
         )
 
@@ -139,6 +106,9 @@ class MagicLinks(Base):
         magic_link_url: str,
         expiration_minutes: Optional[int] = None,
         attributes: Optional[Dict] = None,
+        first_name: Optional[str] = None,
+        last_name: Optional[str] = None,
+        middle_name: Optional[str] = None,
     ):
         attributes = self._validate_attributes(attributes)
         return self._post(
@@ -150,6 +120,11 @@ class MagicLinks(Base):
                 "magic_link_url": magic_link_url,
                 "expiration_minutes": expiration_minutes,
                 "attributes": attributes,
+                "name": {
+                    "first_name": first_name,
+                    "middle_name": middle_name,
+                    "last_name": last_name,
+                },
             },
         )
 
@@ -157,7 +132,6 @@ class MagicLinks(Base):
         self,
         email: str,
     ):
-        attributes = self._validate_attributes(attributes)
         return self._post(
             "{0}/revoke_invite".format(
                 self.magic_link_url,
