@@ -2,7 +2,6 @@ from typing import Dict, Optional
 
 from .base import Base
 
-
 class Users(Base):
     @property
     def user_url(self):
@@ -18,6 +17,7 @@ class Users(Base):
     def create(
         self,
         email: str,
+        phone_number: str = None,
         first_name: str = None,
         last_name: str = None,
         middle_name: str = None,
@@ -25,6 +25,7 @@ class Users(Base):
     ):
         data = {
             "email": email,
+            "phone_number": phone_number,
             "name": {
                 "first_name": first_name,
                 "middle_name": middle_name,
@@ -38,8 +39,18 @@ class Users(Base):
     def get(self, user_id: str):
         return self._get("{0}/{1}".format(self.user_url, user_id))
 
-    def get_invited_users(self):
-        return self._get("{0}/{1}".format(self.user_url, "invites"))
+    def get_pending_users(
+        self,
+        limit: Optional[int] = None,
+        starting_after_id: Optional[str] = None
+    ):
+        query_params = {}
+        if limit:
+            query_params.update({"limit": str(limit)})
+        if starting_after_id:
+            query_params.update({"starting_after_id": starting_after_id})
+
+        return self._get("{0}/{1}".format(self.user_url, "pending"), query_params)
 
     def delete(self, user_id: str):
         return self._delete("{0}/{1}".format(self.user_url, user_id))
@@ -47,7 +58,8 @@ class Users(Base):
     def update(
         self,
         user_id: str,
-        email: Optional[str] = None,
+        emails: Optional[list[str]] = None,
+        phone_numbers: Optional[list[str]] = None,
         first_name: Optional[str] = None,
         middle_name: Optional[str] = None,
         last_name: Optional[str] = None,
@@ -55,8 +67,6 @@ class Users(Base):
     ):
         data = {}
         name = {}
-        if email:
-            data.update({"email": email})
         if first_name:
             name.update({"first_name": first_name})
         if middle_name:
@@ -65,10 +75,26 @@ class Users(Base):
             name.update({"last_name": last_name})
         if name:
             data.update({"name": name})
+
+        if emails:
+            ems = []
+            for email in emails:
+                ems.append({"email": email})
+            data.update({"emails": ems})
+
+        if phone_numbers:
+            pns = []
+            for phone_number in phone_numbers:
+                pns.append({"phone_number": phone_number})
+            data.update({"phone_numbers": pns})
+
         if attributes and self._validate_attributes(attributes):
             data.update({"attributes": attributes})
 
         return self._put("{0}/{1}".format(self.user_url, user_id), data)
 
-    def delete_email(self, user_id: str, email: str):
-        return self._delete("{0}/{1}/emails/{2}".format(self.user_url, user_id, email))
+    def delete_email(self, email_id: str):
+        return self._delete("{0}/emails/{1}".format(self.user_url, email_id))
+
+    def delete_phone_number(self, phone_id: str):
+        return self._delete("{0}/phone_numbers/{1}".format(self.user_url, phone_id))
